@@ -4,17 +4,18 @@
 
 ##generateCol is internaly used by plot.Boruta and plotZHistory
 generateCol<-function(x,colCode,col,numShadow){
-        #Checking arguments
-        if(is.null(col) & length(colCode)!=4) stop('colCode should have 4 elements.');
-        #Generating col
-        if(is.null(col)){
-                rep(colCode[4],length(x$finalDecision)+numShadow)->cc;
-                cc[c(x$finalDecision=='Confirmed',rep(FALSE,numShadow))]<-colCode[1];
-                cc[c(x$finalDecision=='Tentative',rep(FALSE,numShadow))]<-colCode[2];
-                cc[c(x$finalDecision=='Rejected',rep(FALSE,numShadow))]<-colCode[3];
-                col=cc;
-        }
-        return(col);
+ #Checking arguments
+ if(is.null(col) & length(colCode)!=4)
+  stop('colCode should have 4 elements.');
+ #Generating col
+ if(is.null(col)){
+  rep(colCode[4],length(x$finalDecision)+numShadow)->cc;
+  cc[c(x$finalDecision=='Confirmed',rep(FALSE,numShadow))]<-colCode[1];
+  cc[c(x$finalDecision=='Tentative',rep(FALSE,numShadow))]<-colCode[2];
+  cc[c(x$finalDecision=='Rejected',rep(FALSE,numShadow))]<-colCode[3];
+  col=cc;
+ }
+ return(col);
 }
 
 ##' @name plot.Boruta
@@ -46,30 +47,30 @@ generateCol<-function(x,colCode,col,numShadow){
 ##' @author Miron B. Kursa
 ##' @S3method plot Boruta
 plot.Boruta<-function(x,colCode=c('green','yellow','red','blue'),sort=TRUE,whichShadow=c(TRUE,TRUE,TRUE),
-                col=NULL,xlab='Attributes',ylab='Importance',...){
-        #Checking arguments
-        if(class(x)!='Boruta') stop('This function needs Boruta object as an argument.');
+  col=NULL,xlab='Attributes',ylab='Importance',...){
+ #Checking arguments
+ if(class(x)!='Boruta') stop('This function needs Boruta object as an argument.');
 
-        #Removal of -Infs and conversion to a list
-        lz<-lapply(1:ncol(x$ImpHistory),function(i) x$ImpHistory[is.finite(x$ImpHistory[,i]),i]);
-        colnames(x$ImpHistory)->names(lz);
+ #Removal of -Infs and conversion to a list
+ lz<-lapply(1:ncol(x$ImpHistory),function(i) x$ImpHistory[is.finite(x$ImpHistory[,i]),i]);
+ colnames(x$ImpHistory)->names(lz);
 
-        #Selection of shadow meta-attributes
-        numShadow<-sum(whichShadow);
-        lz[c(rep(TRUE,length(x$finalDecision)),whichShadow)]->lz;
+ #Selection of shadow meta-attributes
+ numShadow<-sum(whichShadow);
+ lz[c(rep(TRUE,length(x$finalDecision)),whichShadow)]->lz;
 
-        #Generating color vector
-        col<-generateCol(x,colCode,col,numShadow);
+ #Generating color vector
+ col<-generateCol(x,colCode,col,numShadow);
 
-        #Ordering boxes due to attribute median ZScore
-        if(sort){
-                ii<-order(sapply(lz,median));
-                lz[ii]->lz; col<-col[ii];
-        }
+ #Ordering boxes due to attribute median ZScore
+ if(sort){
+  ii<-order(sapply(lz,median));
+  lz[ii]->lz; col<-col[ii];
+ }
 
-        #Final plotting
-        boxplot(lz,xlab=xlab,ylab=ylab,col=col,...);
-        invisible(x);
+ #Final plotting
+ boxplot(lz,xlab=xlab,ylab=ylab,col=col,...);
+ invisible(x);
 }
 
 ##' @name plotImpHistory
@@ -99,15 +100,14 @@ plot.Boruta<-function(x,colCode=c('green','yellow','red','blue'),sort=TRUE,which
 ##' @author Miron B. Kursa
 ##' @export plotImpHistory
 plotImpHistory<-function(x,colCode=c('green','yellow','red','blue'),showRounds=TRUE,col=NULL,type="l",lty=1,pch=0,
-                xlab='Classifier run',ylab='Importance',...){
-        #Checking arguments
-        if(class(x)!='Boruta') stop('This function needs Boruta object as an argument.');
-        col<-generateCol(x,colCode,col,3);
-        #Final plotting
-        matplot(0:(nrow(x$ImpHistory)-1),x$ImpHistory,xlab=xlab,ylab=ylab,col=col,type=type,lty=lty,pch=pch,...);
-        if(showRounds) abline(v=(0:3)*x$roundRuns,col="gray");
-        invisible(x);
+  xlab='Classifier run',ylab='Importance',...){
+ #Checking arguments
+ if(class(x)!='Boruta')
+  stop('This function needs Boruta object as an argument.');
+ col<-generateCol(x,colCode,col,3);
+
+ #Final plotting
+ matplot(0:(nrow(x$ImpHistory)-1),x$ImpHistory,xlab=xlab,ylab=ylab,col=col,type=type,lty=lty,pch=pch,...);
+ if(showRounds) abline(v=(0:3)*x$roundRuns,col="gray");
+ invisible(x);
 }
-
-
-
